=============================================
Welcome to oci-feature-store's documentation!
=============================================

Feature Store
=============

|PyPI|_ |PysparkConda|_ |Notebook Examples|_ |Delta|_ |PySpark|_ |Great Expectations|_ |Pandas|_ |PyArrow|_

.. |PyPI| image:: https://img.shields.io/badge/python-3.8-blue?style=for-the-badge&logo=pypi&logoColor=white
..  _PyPI: https://pypi.org/project/oracle-ads/
.. |PysparkConda| image:: https://img.shields.io/badge/fspyspark32_p38_cpu_v2-1.0-blue?style=for-the-badge&logo=pypi&logoColor=white
..  _PysparkConda: https://docs.oracle.com/en-us/iaas/data-science/using/conda-pyspark-fam.htm
.. |Notebook Examples| image:: https://img.shields.io/badge/docs-notebook--examples-blue?style=for-the-badge&logo=pypi&logoColor=white
..  _Notebook Examples: https://github.com/oracle-samples/oci-data-science-ai-samples/tree/master/notebook_examples
.. |Delta| image:: https://img.shields.io/badge/delta-2.0.1-blue?style=for-the-badge&logo=pypi&logoColor=white
..  _Delta: https://delta.io/
.. |PySpark| image:: https://img.shields.io/badge/pyspark-3.2.1-blue?style=for-the-badge&logo=pypi&logoColor=white
..  _PySpark: https://spark.apache.org/docs/3.2.1/api/python/index.html
.. |Great Expectations| image:: https://img.shields.io/badge/greatexpectations-0.17.19-blue?style=for-the-badge&logo=pypi&logoColor=white
..  _Great Expectations: https://greatexpectations.io/
.. |Pandas| image:: https://img.shields.io/badge/pandas-1.5.3-blue?style=for-the-badge&logo=pypi&logoColor=white
..  _Pandas: https://pandas.pydata.org/
.. |PyArrow| image:: https://img.shields.io/badge/pyarrow-11.0.0-blue?style=for-the-badge&logo=pypi&logoColor=white
..  _PyArrow: https://arrow.apache.org/docs/python/index.html

.. toctree::
    :maxdepth: 2
    :caption: Getting started:

    overview
    setup_feature_store
    quickstart

.. toctree::
    :maxdepth: 2
    :caption: Feature store entities:

    feature_store
    entity
    transformation
    feature_group
    feature_group_job
    dataset
    dataset_job

.. toctree::
    :maxdepth: 2
    :caption: Feature store concepts:

    cicd
    statistics
    feature_validation
    data_versioning
    ui

.. toctree::
    :maxdepth: 2
    :caption: Demo and examples:

    demo
    notebook


.. toctree::
    :maxdepth: 2
    :caption: Release notes:

    release_notes

.. toctree::
    :hidden:
    :maxdepth: 5
    :caption: Classes:

    module

License
+++++++

Copyright (c) 2020, 2022 Oracle and/or its affiliates. Licensed under the `Universal Permissive License v1.0 <https://oss.oracle.com/licenses/upl/>`_
